from typing import Dict, List
import logging

from sqlalchemy.exc import IntegrityError, SQLAlchemyError, DatabaseError as SqlAlchemyDatabaseError

from utils.errors.database import DatabaseError, DuplicateEntryError, DatabaseConnectionError
from models import BooksOverview
from database.manager import DatabaseManager

logger = logging.getLogger(__name__)


def fetch_all_book_overviews() -> List[BooksOverview]:
    with DatabaseManager.get_session() as session:
        try:
            return session.query(BooksOverview).all()
        except SqlAlchemyDatabaseError as e:
            logger.critical("Connection with database interrupted")
            raise DatabaseConnectionError("Connection with database interrupted") from e
        except SQLAlchemyError as e:
            logger.error(f"An error occured when fetching all books: {e}")
            raise DatabaseError("An error occured when fetching all books") from e


__all__ = ["fetch_all_book_overviews"]
