from PySide6.QtGui import QGuiApplication, QIcon
from PySide6.QtWidgets import QMainWindow, QApplication, QTabWidget

from ui.main_tabs import BookOverviewList, MemberList
from ui.menu_bar import MenuBar


class LibraryWindow(QMainWindow):
    def __init__(self):
        super().__init__()

        # Set up main window properties
        self.setWindowTitle("Library App")
        self.setWindowIcon(QIcon.fromTheme("x-content-ebook-reader"))
        self.setGeometry(0, 0, 800, 600)

        self.center_window()

        self.setMenuBar(MenuBar(self))

        # Central widget and layout
        central_widget = QTabWidget()
        self.setCentralWidget(central_widget)

        self.dashboard = BookOverviewList()
        self.member_list = MemberList()
        central_widget.addTab(self.dashboard, "Dashboard")
        central_widget.addTab(self.member_list, "Members")

    def center_window(self):
        # Get the screen geometry
        screen = QApplication.primaryScreen()
        screen_geometry = screen.geometry()

        # Get the dimensions of the window
        window_geometry = self.frameGeometry()

        # Calculate the center point of the screen
        center_point = screen_geometry.center()

        # Move the window geometry to the center of the screen
        window_geometry.moveCenter(center_point)

        # Move the window to the calculated geometry
        self.move(window_geometry.topLeft())

    def redraw_book_cards(self):
        self.dashboard.redraw_cards()